@@ -4,15 +4,18 @@ use strict;
 use warnings;
 use utf8;
 
+use Test::BDD::Cucumber::Definitions::Base::Ru;
 use Test::BDD::Cucumber::Definitions::File::Ru;
 use Test::BDD::Cucumber::Definitions::HTTP::Ru;
 use Test::BDD::Cucumber::Definitions::Struct::Ru;
 use Test::BDD::Cucumber::Definitions::Var::Ru;
 use Test::BDD::Cucumber::Definitions::Zip::Ru;
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 sub import {
+
+    Test::BDD::Cucumber::Definitions::Base::Ru->import;
     Test::BDD::Cucumber::Definitions::File::Ru->import;
     Test::BDD::Cucumber::Definitions::HTTP::Ru->import;
     Test::BDD::Cucumber::Definitions::Struct::Ru->import;
